@@ -20,7 +20,7 @@ import re
 from typing import Optional, Union
 
 from ...image_processing_utils import BatchFeature
-from ...image_utils import ImageInput, is_batched
+from ...image_utils import ImageInput
 from ...processing_utils import ImagesKwargs, ProcessingKwargs, ProcessorMixin, TextKwargs, Unpack
 from ...tokenization_utils import AddedToken
 from ...tokenization_utils_base import BatchEncoding, TextInput
@@ -134,7 +134,7 @@ class Kosmos2Processor(ProcessorMixin):
 
     def __call__(
         self,
-        images: ImageInput = None,
+        images: Optional[ImageInput] = None,
         text: Union[TextInput, list[TextInput]] = None,
         audio=None,
         videos=None,
@@ -342,7 +342,7 @@ class Kosmos2Processor(ProcessorMixin):
     def preprocess_examples(
         self,
         texts: Union[TextInput, list[TextInput]],
-        images: ImageInput = None,
+        images: Optional[ImageInput] = None,
         bboxes: BboxInput = None,
         num_image_tokens: Optional[int] = 64,
     ) -> Union[str, list[str]]:
@@ -372,7 +372,7 @@ class Kosmos2Processor(ProcessorMixin):
 
         if images is None:
             images = [None] * len(texts)
-        elif not is_batched(images):
+        elif not isinstance(images, list):
             images = [images]
         if len(texts) != len(images):
             raise ValueError(
@@ -578,7 +578,7 @@ def patch_index_to_coordinate(ul_idx: int, lr_idx: int, num_patches_per_side: in
 def extract_entities_with_patch_indices(text):
     """Extract entities contained in `text`. The bounding bboxes is given in the form of patch indices.
 
-    This functioin is only intended to be used within `clean_text_and_extract_entities_with_bboxes` where further
+    This function is only intended to be used within `clean_text_and_extract_entities_with_bboxes` where further
     processing happens, including converting to normalized coordinates and whitespace character cleaning up.
 
     Examples:
