@@ -287,7 +287,7 @@ class MetaClip2PreTrainedModel(PreTrainedModel):
 
 
 class MetaClip2TextTransformer(CLIPTextTransformer):
-    @check_model_inputs
+    @check_model_inputs(tie_last_hidden_states=False)
     @auto_docstring
     def forward(
         self,
