@@ -329,7 +329,7 @@ class Qwen2VLConfig(PretrainedConfig):
     def __setattr__(self, key, value):
         if (
             (text_config := super().__getattribute__("__dict__").get("text_config")) is not None
-            and key not in ["dtype", "_attn_implementation_internal"]
+            and key not in ["_name_or_path", "model_type", "dtype", "_attn_implementation_internal"]
             and key in text_config.__dict__
         ):
             setattr(text_config, key, value)
@@ -338,6 +338,8 @@ class Qwen2VLConfig(PretrainedConfig):
 
     def __getattribute__(self, key):
         if "text_config" in super().__getattribute__("__dict__") and key not in [
+            "_name_or_path",
+            "model_type",
             "dtype",
             "_attn_implementation_internal",
         ]:
