@@ -57,7 +57,7 @@ class UniSpeechSatForPreTrainingOutput(ModelOutput):
     r"""
     loss (*optional*, returned when model is in train mode, `torch.FloatTensor` of shape `(1,)`):
         Total loss as the sum of the contrastive loss (L_m) and the diversity loss (L_d) as stated in the [official
-        paper](https://arxiv.org/pdf/2006.11477.pdf) . (classification) loss.
+        paper](https://huggingface.co/papers/2006.11477).
     logits (`torch.FloatTensor` of shape `(batch_size, sequence_length, config.proj_codevector_dim)`, *optional*):
         Prediction scores of the contrastive loss model, i.e. the output of the model before the final softmax.
     projected_states (`torch.FloatTensor` of shape `(batch_size, sequence_length, config.proj_codevector_dim)`):
@@ -101,7 +101,7 @@ class UniSpeechSatEncoderStableLayerNorm(Wav2Vec2EncoderStableLayerNorm):
 
 class UniSpeechSatGumbelVectorQuantizer(Wav2Vec2GumbelVectorQuantizer):
     def __init__(self, config):
-        super().__init__()
+        super().__init__(config)
         self.weight_proj = nn.Linear(config.hidden_size, self.num_groups * self.num_vars)
 
     @staticmethod
@@ -227,7 +227,7 @@ UniSpeechSatBaseModelOutput = Wav2Vec2BaseModelOutput
 
 class UniSpeechSatModel(UniSpeechSatPreTrainedModel, Wav2Vec2Model):
     def __init__(self, config: UniSpeechSatConfig):
-        UniSpeechSatPreTrainedModel.__init__(config)
+        UniSpeechSatPreTrainedModel.__init__(self, config)
         self.config = config
         self.feature_extractor = UniSpeechSatFeatureEncoder(config)
         self.feature_projection = UniSpeechSatFeatureProjection(config)
