@@ -48,34 +48,11 @@ logger = logging.get_logger(__name__)
 
 if is_torch_available():
     # required for @can_return_tuple decorator to work with torchdynamo
-    import torch  # noqa: F401
+    import torch
 
     from ..model_debugging_utils import model_addition_debugger_context
 
 
-class cached_property(property):
-    """
-    Descriptor that mimics @property but caches output in member variable.
-
-    From tensorflow_datasets
-
-    Built-in in functools from Python 3.8.
-    """
-
-    def __get__(self, obj, objtype=None):
-        # See docs.python.org/3/howto/descriptor.html#properties
-        if obj is None:
-            return self
-        if self.fget is None:
-            raise AttributeError("unreadable attribute")
-        attr = "__cached_" + self.fget.__name__
-        cached = getattr(obj, attr, None)
-        if cached is None:
-            cached = self.fget(obj)
-            setattr(obj, attr, cached)
-        return cached
-
-
 # vendored from distutils.util
 def strtobool(val):
     """Convert a string representation of truth to true (1) or false (0).
@@ -403,6 +380,8 @@ class ModelOutput(OrderedDict):
             # if we provided an iterator as first field and the iterator is a (key, value) iterator
             # set the associated fields
             if first_field_iterator:
+                # reset first field to None
+                setattr(self, class_fields[0].name, None)
                 for idx, element in enumerate(iterator):
                     if not isinstance(element, (list, tuple)) or len(element) != 2 or not isinstance(element[0], str):
                         if idx == 0:
@@ -463,7 +442,7 @@ class ModelOutput(OrderedDict):
         args = tuple(getattr(self, field.name) for field in fields(self))
         return callable, args, *remaining
 
-    def to_tuple(self) -> tuple[Any]:
+    def to_tuple(self) -> tuple:
         """
         Convert self to a tuple containing all the attributes/keys that are not `None`.
         """
@@ -836,12 +815,11 @@ def filter_out_non_signature_kwargs(extra: Optional[list] = None):
 
 class TransformersKwargs(TypedDict, total=False):
     """
-    Keyword arguments to be passed to the loss function
+    Keyword arguments to be passed to the forward pass of a `PreTrainedModel`.
 
     Attributes:
         num_items_in_batch (`Optional[torch.Tensor]`, *optional*):
-            Number of items in the batch. It is recommended to pass it when
-            you are doing gradient accumulation.
+            Number of items in the batch. It is recommended to pass it when you are doing gradient accumulation.
         output_hidden_states (`Optional[bool]`, *optional*):
             Most of the models support outputting all hidden states computed during the forward pass.
         output_attentions (`Optional[bool]`, *optional*):
@@ -961,134 +939,185 @@ class OutputRecorder:
     """
 
     target_class: "type[torch.nn.Module]"
-    index: Optional[int] = 0
+    index: int = 0
     layer_name: Optional[str] = None
     class_name: Optional[str] = None
 
 
-def check_model_inputs(func):
+def check_model_inputs(func=None, *, tie_last_hidden_states=True):
     """
     Decorator to intercept specific layer outputs without using hooks.
     Compatible with torch.compile (Dynamo tracing).
+
+    Args:
+        tie_last_hidden_states (`bool`, *optional*, defaults to `True`):
+            Whether to overwrite `out.hidden_states[-1]` with the `out.last_hidden_state`.
+            This is true for all language models and should be toggled off only if
+            `out.hidden_states[-1]` has to be the hidden state before last layer norm, which
+            is needed for some vision models (e.g. CLIP, SigLIP)
     """
 
-    @wraps(func)
-    def wrapper(self, *args, **kwargs):
-        use_cache = (
-            kwargs["use_cache"] if kwargs.get("use_cache") is not None else getattr(self.config, "use_cache", None)
-        )
-        if use_cache is not None:
-            if getattr(self, "gradient_checkpointing", False) and self.training and use_cache:
-                logger.warning_once(
-                    "`use_cache=True` is incompatible with gradient checkpointing. Setting `use_cache=False`."
-                )
-                use_cache = False
-
-            kwargs["use_cache"] = use_cache
-
-        return_dict = kwargs.pop("return_dict", None)
-        if return_dict is None:
-            return_dict = getattr(self.config, "return_dict", True)
-
-        all_args = kwargs.copy()
-        if "kwargs" in all_args:
-            for k, v in all_args["kwargs"].items():
-                all_args[k] = v
-
-        capture_flags = _CAN_RECORD_REGISTRY.get(str(self.__class__), {})  # there is a weak ref for executorch
-        recordable_keys = {
-            f"output_{k}": all_args.get(
-                f"output_{k}",
-                getattr(
-                    self.config,
-                    f"output_{k}",
-                    all_args.get("output_attentions", getattr(self.config, "output_attentions", False)),
-                ),
+    def wrapped_fn(func):
+        @wraps(func)
+        def wrapper(self, *args, **kwargs):
+            use_cache = (
+                kwargs["use_cache"] if kwargs.get("use_cache") is not None else getattr(self.config, "use_cache", None)
             )
-            for k in capture_flags
-        }
-        collected_outputs = defaultdict(tuple)
-        monkey_patched_layers = []
+            if use_cache is not None:
+                if getattr(self, "gradient_checkpointing", False) and self.training and use_cache:
+                    logger.warning_once(
+                        "`use_cache=True` is incompatible with gradient checkpointing. Setting `use_cache=False`."
+                    )
+                    use_cache = False
 
-        def make_capture_wrapper(module, orig_forward, key, index):
-            @wraps(orig_forward)
-            def wrapped_forward(*args, **kwargs):
-                if key == "hidden_states" and len(collected_outputs[key]) == 0:
-                    collected_outputs[key] += (args[0],)
-                if kwargs.get("debug_io", False):
-                    with model_addition_debugger_context(
-                        module, kwargs.get("debug_io_dir", "~/model_debug"), kwargs.get("prune_layers")
-                    ):
-                        output = orig_forward(*args, **kwargs)
-                else:
-                    output = orig_forward(*args, **kwargs)
-                if not isinstance(output, tuple):
-                    collected_outputs[key] += (output,)
-                elif output[index] is not None:
-                    if key not in collected_outputs:
-                        collected_outputs[key] = (output[index],)
+                kwargs["use_cache"] = use_cache
+
+            return_dict = kwargs.pop("return_dict", None)
+            if return_dict is None:
+                return_dict = getattr(self.config, "return_dict", True)
+
+            all_args = kwargs.copy()
+            if "kwargs" in all_args:
+                for k, v in all_args["kwargs"].items():
+                    all_args[k] = v
+
+            capture_flags = _CAN_RECORD_REGISTRY.get(str(self.__class__), {})  # there is a weak ref for executorch
+            recordable_keys = {
+                f"output_{k}": all_args.get(
+                    f"output_{k}",
+                    getattr(
+                        self.config,
+                        f"output_{k}",
+                        all_args.get("output_attentions", getattr(self.config, "output_attentions", False)),
+                    ),
+                )
+                for k in capture_flags
+            }
+
+            # We let cross attentions to be saved separately because some models add `cross-attn` layer
+            # when certain condtions are met. Let's output cross attention if attentions are requested (for BC)
+            if "output_attentions" in recordable_keys:
+                recordable_keys["output_cross_attentions"] = recordable_keys["output_attentions"]
+
+            collected_outputs = defaultdict(tuple)
+            monkey_patched_layers = []
+
+            # Check attention implementation is properly set for capturing attention outputs
+            if recordable_keys.get("output_attentions", False):
+                supported_attn = ["eager", "eager_paged", "flex_attention"]
+                config_attn = getattr(self.config, "_attn_implementation", None)
+                sub_configs = [getattr(self.config, key, None) for key in self.config.sub_configs]
+                sub_configs_attn = [
+                    getattr(config, "_attn_implementation", None) for config in sub_configs if config is not None
+                ]
+                if config_attn not in supported_attn or any(attn not in supported_attn for attn in sub_configs_attn):
+                    warnings.warn(
+                        f"`output_attentions=True` is not supported with `attn_implementation` other than {supported_attn}. "
+                        "Please use `model.set_attn_implementation('eager')` to enable capturing attention outputs.",
+                        UserWarning,
+                    )
+
+            def make_capture_wrapper(module, orig_forward, key, index):
+                @wraps(orig_forward)
+                def wrapped_forward(*args, **kwargs):
+                    if key == "hidden_states" and len(collected_outputs[key]) == 0:
+                        collected_outputs[key] += (args[0],)
+                    if kwargs.get("debug_io", False):
+                        with model_addition_debugger_context(
+                            module, kwargs.get("debug_io_dir", "~/model_debug"), kwargs.get("prune_layers")
+                        ):
+                            output = orig_forward(*args, **kwargs)
                     else:
-                        collected_outputs[key] += (output[index],)
-                return output
+                        output = orig_forward(*args, **kwargs)
+                    if not isinstance(output, tuple):
+                        collected_outputs[key] += (output,)
+                    elif output[index] is not None:
+                        if key not in collected_outputs:
+                            collected_outputs[key] = (output[index],)
+                        else:
+                            collected_outputs[key] += (output[index],)
+                    return output
 
-            return wrapped_forward
+                return wrapped_forward
 
-        if any(recordable_keys.values()):
-            capture_tasks = []
-            for key, layer_specs in capture_flags.items():
-                if not recordable_keys.get(f"output_{key}", False):
-                    continue
-                if not isinstance(layer_specs, list):
-                    layer_specs = [layer_specs]
-                for specs in layer_specs:
-                    if not isinstance(specs, OutputRecorder):
-                        index = 0 if "hidden_states" in key else 1
-                        class_name = None if not isinstance(specs, str) else specs
-                        target_class = specs if not isinstance(specs, str) else None
-                        specs = OutputRecorder(target_class=target_class, index=index, class_name=class_name)
-                    capture_tasks.append((key, specs))
+            if any(recordable_keys.values()):
+                capture_tasks = []
+                for key, layer_specs in capture_flags.items():
+                    if not recordable_keys.get(f"output_{key}", False):
+                        continue
+                    if not isinstance(layer_specs, list):
+                        layer_specs = [layer_specs]
+                    for specs in layer_specs:
+                        if not isinstance(specs, OutputRecorder):
+                            index = 0 if "hidden_states" in key else 1
+                            class_name = None if not isinstance(specs, str) else specs
+                            target_class = specs if not isinstance(specs, str) else None
+                            specs = OutputRecorder(target_class=target_class, index=index, class_name=class_name)
+                        capture_tasks.append((key, specs))
 
-            for name, module in self.named_modules():
-                for key, specs in capture_tasks:
-                    # The second check is for multimodals where only backbone layer suffix is available
-                    if (specs.target_class is not None and isinstance(module, specs.target_class)) or (
-                        specs.class_name is not None and name.endswith(specs.class_name)
-                    ):
-                        if specs.layer_name is not None and specs.layer_name not in name:
-                            continue
-                        # Monkey patch forward
-                        original_forward = module.forward
-                        module.forward = make_capture_wrapper(module, original_forward, key, specs.index)
-                        monkey_patched_layers.append((module, original_forward))
+                for name, module in self.named_modules():
+                    for key, specs in capture_tasks:
+                        # The second check is for multimodals where only backbone layer suffix is available
+                        if (specs.target_class is not None and isinstance(module, specs.target_class)) or (
+                            specs.class_name is not None and name.endswith(specs.class_name)
+                        ):
+                            if specs.layer_name is not None and specs.layer_name not in name:
+                                continue
+                            # Monkey patch forward
+                            original_forward = module.forward
+                            module.forward = make_capture_wrapper(module, original_forward, key, specs.index)
+                            monkey_patched_layers.append((module, original_forward))
 
-        outputs = func(self, *args, **kwargs)
-        # Restore original forward methods
-        for module, original_forward in monkey_patched_layers:
-            module.forward = original_forward
+            try:
+                outputs = func(self, *args, **kwargs)
+            except TypeError as original_exception:
+                # If we get a TypeError, it's possible that the model is not receiving the recordable kwargs correctly.
+                # Get a TypeError even after removing the recordable kwargs -> re-raise the original exception
+                # Otherwise -> we're probably missing `**kwargs` in the decorated function
+                kwargs_without_recordable = {k: v for k, v in kwargs.items() if k not in recordable_keys}
+                try:
+                    outputs = func(self, *args, **kwargs_without_recordable)
+                except TypeError:
+                    raise original_exception
+                raise TypeError(
+                    "Missing `**kwargs` in the signature of the `@check_model_inputs`-decorated function "
+                    f"({func.__qualname__})"
+                )
 
-        # Inject collected outputs into model output
-        for key in collected_outputs:
-            if key == "hidden_states":
-                collected_outputs[key] = collected_outputs[key][:-1]
-                if hasattr(outputs, "vision_hidden_states"):
-                    collected_outputs[key] += (outputs.vision_hidden_states,)
-                elif hasattr(outputs, "last_hidden_state"):
-                    collected_outputs[key] += (outputs.last_hidden_state,)
+            # Restore original forward methods
+            for module, original_forward in monkey_patched_layers:
+                module.forward = original_forward
 
-                outputs[key] = collected_outputs[key]
-            elif key == "attentions":
-                if isinstance(capture_flags[key], list) and len(capture_flags[key]) == 2:
-                    outputs[key] = collected_outputs[key][0::2]
-                    outputs["cross_" + key] = collected_outputs[key][1::2]
+            # Inject collected outputs into model output
+            for key in collected_outputs:
+                if key == "hidden_states":
+                    if not tie_last_hidden_states:
+                        pass
+                    elif hasattr(outputs, "vision_hidden_states"):
+                        collected_outputs[key] = collected_outputs[key][:-1]
+                        collected_outputs[key] += (outputs.vision_hidden_states,)
+                    elif hasattr(outputs, "last_hidden_state"):
+                        collected_outputs[key] = collected_outputs[key][:-1]
+                        collected_outputs[key] += (outputs.last_hidden_state,)
+
+                    outputs[key] = collected_outputs[key]
+                elif key == "attentions":
+                    if isinstance(capture_flags[key], list) and len(capture_flags[key]) == 2:
+                        outputs[key] = collected_outputs[key][0::2]
+                        outputs["cross_" + key] = collected_outputs[key][1::2]
+                    else:
+                        outputs[key] = collected_outputs[key]
                 else:
                     outputs[key] = collected_outputs[key]
-            else:
-                outputs[key] = collected_outputs[key]
-        if return_dict is False:
-            outputs = outputs.to_tuple()
-        return outputs
+            if return_dict is False:
+                outputs = outputs.to_tuple()
+            return outputs
 
-    return wrapper
+        return wrapper
+
+    if func is not None:
+        return wrapped_fn(func)
+    return wrapped_fn
 
 
 class GeneralInterface(MutableMapping):
