@@ -14,10 +14,11 @@
 """Testing suite for the PyTorch EfficientNet model."""
 
 import unittest
+from functools import cached_property
 
 from transformers import EfficientNetConfig
 from transformers.testing_utils import is_pipeline_test, require_torch, require_vision, slow, torch_device
-from transformers.utils import cached_property, is_torch_available, is_vision_available
+from transformers.utils import is_torch_available, is_vision_available
 
 from ...test_configuration_common import ConfigTester
 from ...test_modeling_common import ModelTesterMixin, floats_tensor, ids_tensor
