@@ -18,7 +18,7 @@ import unittest
 
 import pytest
 
-from transformers import Phi3Config, StaticCache, is_torch_available
+from transformers import StaticCache, is_torch_available
 from transformers.models.auto.configuration_auto import AutoConfig
 from transformers.testing_utils import (
     Expectations,
@@ -40,7 +40,6 @@ if is_torch_available():
         Phi3ForTokenClassification,
         Phi3Model,
     )
-    from transformers.models.phi3.modeling_phi3 import Phi3RotaryEmbedding
 
     end_of_text_token = 32000
 
@@ -87,21 +86,12 @@ if is_torch_available():
 
 
 class Phi3ModelTester(CausalLMModelTester):
-    config_class = Phi3Config
     if is_torch_available():
         base_model_class = Phi3Model
-        causal_lm_class = Phi3ForCausalLM
-        sequence_class = Phi3ForSequenceClassification
-        token_class = Phi3ForTokenClassification
 
 
 @require_torch
 class Phi3ModelTest(CausalLMModelTest, unittest.TestCase):
-    all_model_classes = (
-        (Phi3Model, Phi3ForCausalLM, Phi3ForSequenceClassification, Phi3ForTokenClassification)
-        if is_torch_available()
-        else ()
-    )
     pipeline_model_mapping = (
         {
             "feature-extraction": Phi3Model,
@@ -113,10 +103,7 @@ class Phi3ModelTest(CausalLMModelTest, unittest.TestCase):
         else {}
     )
 
-    test_headmasking = False
-    test_pruning = False
     model_tester_class = Phi3ModelTester
-    rotary_embedding_layer = Phi3RotaryEmbedding
 
 
 @slow
