@@ -76,7 +76,7 @@ class ImageClassificationPipelineTests(unittest.TestCase):
         image_processor=None,
         feature_extractor=None,
         processor=None,
-        torch_dtype="float32",
+        dtype="float32",
     ):
         image_classifier = ImageClassificationPipeline(
             model=model,
@@ -84,7 +84,7 @@ class ImageClassificationPipelineTests(unittest.TestCase):
             feature_extractor=feature_extractor,
             image_processor=image_processor,
             processor=processor,
-            torch_dtype=torch_dtype,
+            dtype=dtype,
             top_k=2,
         )
         examples = [
@@ -187,7 +187,7 @@ class ImageClassificationPipelineTests(unittest.TestCase):
     @require_torch
     def test_torch_float16_pipeline(self):
         image_classifier = pipeline(
-            "image-classification", model="hf-internal-testing/tiny-random-vit", torch_dtype=torch.float16
+            "image-classification", model="hf-internal-testing/tiny-random-vit", dtype=torch.float16
         )
         outputs = image_classifier("http://images.cocodataset.org/val2017/000000039769.jpg")
 
@@ -199,7 +199,7 @@ class ImageClassificationPipelineTests(unittest.TestCase):
     @require_torch
     def test_torch_bfloat16_pipeline(self):
         image_classifier = pipeline(
-            "image-classification", model="hf-internal-testing/tiny-random-vit", torch_dtype=torch.bfloat16
+            "image-classification", model="hf-internal-testing/tiny-random-vit", dtype=torch.bfloat16
         )
         outputs = image_classifier("http://images.cocodataset.org/val2017/000000039769.jpg")
 
